use strict;
use warnings;
use Test::More tests => 4;

use_ok 'Clustericious::Config';
use_ok 'Clustericious::Config::Password';
use_ok 'Clustericious::Config::Helpers';
use_ok 'Test::Clustericious::Config';
